@@ -20,11 +20,13 @@ def derive_condition_node_type(condition_key: str) -> ConditionNodeType:
     """
     Returns the corresponding type of condition node for a given condition key
     """
+    if condition_key.endswith("P"):
+        return ConditionNodeType.PACKAGE
+        # todo: implement wiederholbarkeiten https://github.com/Hochfrequenz/ahbicht/issues/96
     if 1 <= int(condition_key) <= 499:
         return ConditionNodeType.REQUIREMENT_CONSTRAINT
     if 500 <= int(condition_key) <= 900:
         return ConditionNodeType.HINT
     if 901 <= int(condition_key) <= 999:
         return ConditionNodeType.FORMAT_CONSTRAINT
-    # todo: add package detection
     raise ValueError("Condition key is not in valid number range.")
