@@ -3,7 +3,7 @@ Tests that the parsed trees are JSON serializable
 """
 import json
 import uuid
-from typing import TypeVar
+from typing import List, TypeVar
 
 import pytest  # type:ignore[import]
 from marshmallow import Schema, ValidationError
@@ -29,6 +29,15 @@ from ahbicht.mapping_results import (
     PackageKeyConditionExpressionMapping,
     PackageKeyConditionExpressionMappingSchema,
 )
+from ahbicht.validation.validation_results import (
+    DataElementValidationResult,
+    DataElementValidationResultSchema,
+    SegmentLevelValidationResult,
+    SegmentLevelValidationResultSchema,
+    ValidationResultInContext,
+    ValidationResultInContextSchema,
+)
+from ahbicht.validation.validation_values import RequirementValidationValue
 
 T = TypeVar("T")
 
@@ -246,6 +255,161 @@ class TestJsonSerialization:
             ahb_expression_evaluation_result, AhbExpressionEvaluationResultSchema(), expected_json_dict
         )
 
+    @pytest.mark.parametrize(
+        "validation_result, expected_json_dict",
+        [
+            pytest.param(
+                SegmentLevelValidationResult(
+                    requirement_validation=RequirementValidationValue.IS_FORBIDDEN_AND_EMPTY, hints="foo"
+                ),
+                {
+                    "requirement_validation": "IS_FORBIDDEN_AND_EMPTY",
+                    "hints": "foo",
+                },
+            ),
+            pytest.param(
+                SegmentLevelValidationResult(requirement_validation=RequirementValidationValue.IS_FORBIDDEN),
+                {
+                    "requirement_validation": "IS_FORBIDDEN",
+                    "hints": None,
+                },
+            ),
+        ],
+    )
+    def test_segment_level_validation_result_serialization(
+        self, validation_result: SegmentLevelValidationResult, expected_json_dict: dict
+    ):
+        _test_serialization_roundtrip(validation_result, SegmentLevelValidationResultSchema(), expected_json_dict)
+
+    @pytest.mark.parametrize(
+        "validation_result, expected_json_dict",
+        [
+            pytest.param(
+                DataElementValidationResult(
+                    requirement_validation=RequirementValidationValue.IS_FORBIDDEN,
+                    format_validation_fulfilled=True,
+                ),
+                {
+                    "requirement_validation": "IS_FORBIDDEN",
+                    "hints": None,
+                    "format_validation_fulfilled": True,
+                    "format_error_message": None,
+                    "possible_values": None,
+                },
+            ),
+            pytest.param(
+                DataElementValidationResult(
+                    requirement_validation=RequirementValidationValue.IS_REQUIRED_AND_FILLED,
+                    hints="foo",
+                    format_validation_fulfilled=False,
+                    format_error_message="bar",
+                ),
+                {
+                    "requirement_validation": "IS_REQUIRED_AND_FILLED",
+                    "hints": "foo",
+                    "format_validation_fulfilled": False,
+                    "format_error_message": "bar",
+                    "possible_values": None,
+                },
+            ),
+            pytest.param(
+                DataElementValidationResult(
+                    requirement_validation=RequirementValidationValue.IS_REQUIRED,
+                    hints="foo",
+                    format_validation_fulfilled=True,
+                    format_error_message=None,
+                    possible_values={"A1": "Ich bin A1", "A2": "Ich bin A2", "Z3": "Ich bin Z3"},
+                ),
+                {
+                    "requirement_validation": "IS_REQUIRED",
+                    "hints": "foo",
+                    "format_validation_fulfilled": True,
+                    "format_error_message": None,
+                    "possible_values": {"A1": "Ich bin A1", "A2": "Ich bin A2", "Z3": "Ich bin Z3"},
+                },
+            ),
+        ],
+    )
+    def test_data_element_validation_result_serialization(
+        self, validation_result: DataElementValidationResult, expected_json_dict: dict
+    ):
+        _test_serialization_roundtrip(validation_result, DataElementValidationResultSchema(), expected_json_dict)
+
+    @pytest.mark.parametrize(
+        "validation_result_in_context, expected_json_dict",
+        [
+            pytest.param(
+                ValidationResultInContext(
+                    discriminator="foo",
+                    validation_result=SegmentLevelValidationResult(
+                        requirement_validation=RequirementValidationValue.IS_FORBIDDEN_AND_EMPTY, hints="foo"
+                    ),
+                ),
+                {
+                    "discriminator": "foo",
+                    "validation_result": {
+                        "requirement_validation": "IS_FORBIDDEN_AND_EMPTY",
+                        "hints": "foo",
+                    },
+                },
+            ),
+        ],
+    )
+    def test_validation_result_in_context_serialization(
+        self, validation_result_in_context: ValidationResultInContext, expected_json_dict: dict
+    ):
+        json_string = ValidationResultInContextSchema().dumps(validation_result_in_context)
+        assert json_string is not None
+        actual_json_dict = json.loads(json_string)
+        assert actual_json_dict == expected_json_dict
+
+    @pytest.mark.parametrize(
+        "list_of_validation_result_in_context, expected_json_dict",
+        [
+            pytest.param(
+                [
+                    ValidationResultInContext(
+                        discriminator="foo",
+                        validation_result=SegmentLevelValidationResult(
+                            requirement_validation=RequirementValidationValue.IS_FORBIDDEN_AND_EMPTY, hints="foo"
+                        ),
+                    ),
+                    ValidationResultInContext(
+                        discriminator="bar",
+                        validation_result=SegmentLevelValidationResult(
+                            requirement_validation=RequirementValidationValue.IS_REQUIRED, hints="bar"
+                        ),
+                    ),
+                ],
+                [
+                    {
+                        "discriminator": "foo",
+                        "validation_result": {
+                            "requirement_validation": "IS_FORBIDDEN_AND_EMPTY",
+                            "hints": "foo",
+                        },
+                    },
+                    {
+                        "discriminator": "bar",
+                        "validation_result": {
+                            "requirement_validation": "IS_REQUIRED",
+                            "hints": "bar",
+                        },
+                    },
+                ],
+            ),
+        ],
+    )
+    def test_list_of_validation_result_in_context_serialization(
+        self,
+        list_of_validation_result_in_context: List[ValidationResultInContext],
+        expected_json_dict: dict,
+    ):
+        json_string = ValidationResultInContextSchema().dumps(list_of_validation_result_in_context, many=True)
+        assert json_string is not None
+        actual_json_dict = json.loads(json_string)
+        assert actual_json_dict == expected_json_dict
+
     @pytest.mark.parametrize(
         "condition_key_condition_text_mapping, expected_json_dict",
         [
@@ -295,12 +459,14 @@ class TestJsonSerialization:
                     format_constraint_keys=["901", "902"],
                     requirement_constraint_keys=["1", "2", "3", "4"],
                     package_keys=["17P"],
+                    time_condition_keys=["UB1", "UB2"],
                 ),
                 {
                     "hint_keys": ["501", "502", "503"],
                     "format_constraint_keys": ["901", "902"],
                     "requirement_constraint_keys": ["1", "2", "3", "4"],
                     "package_keys": ["17P"],
+                    "time_condition_keys": ["UB1", "UB2"],
                 },
             ),
         ],
